## Copyright (C) 2005, 2006 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} __uiobject_adopt__ (@var{parent}, @var{child}, @var{field})
## Add @var{child} to the list of children in @var{parent}.  If
## @var{field} is given, add it to that property instead of the
## "children" property.  @var{child} may be a handle vector.
## @seealso{__uiobject_orphan__}
## @end deftypefn

## Author: jwe

function s = __uiobject_adopt__ (parent, child, field)

  if ((nargin < 3) || isempty (field))
    field = "children";
  endif

  if (nargin > 3) || (nargin < 2)
    usage ("__uiobject_adopt__ (parent, child, field)");
  elseif (~ ischar (field))
    error ("__uiobject_adopt__: field must be a character string");
  elseif (numel (parent) ~= 1)
    error ("__uiobject_adopt__: only one parent may be given");
  elseif (~ ishandle (parent))
    error ("__uiobject_adopt__: parent must be a handle");
  elseif any (~ ishandle (child(:)))
    error ("__uiobject_adopt__: children must be handles");
  endif

  if ((nargin == 2) || (nargin == 3))
    ## remove it from it's current parent if necessary (making adopt
    ## move from another parent as well)
    __uiobject_orphan__ (child);

    obj = get (parent);
    if (! isempty (obj))
      kids = get (parent, field);
      set (parent, field, [kids, child(:)]);
      ## Remove them from the orphan list
      orph = get (0, "orphans");
      orph = orph(~ ismember (orph, child));
      set (0, "orphans", orph);
    else
      error ("__uiobject_adopt__: expecting parent to be a handle");
    endif
  else
    usage ("__uiobject_adopt__ (parent, child)");
  endif

endfunction
