## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} __uiobject_autolabel_axes__ (h)
## Create automatic labels for axes with handle @var{h}.
## @end deftypefn

## Author: Bill Denney

function __uiobject_autolabel_axes__ (h)

  s = get(h);
  if (~ strcmpi (s.type, "axes"))
    error ("__uiobject_autolabel_axes__: object type must be axes");
  endif

  ## FIXME: this could probably be better done with another sub-function
  ## instead of code repetition.

  ## check the x axis
  if strcmpi (s.xticklabelmode, "auto")
    ## delete any old axis labels
    ## FIXME: Perhaps we should check if there is a change to the axis
    ## here before doing all this work
    delete (s.xticklabelobject);

    ## create the new axis labels
    for i = 1:length (s.xtick)
      hc = __uiobject_create_object__ ("text", ...
				       "parent", h, ...
				       "string", num2str (s.xtick(i)), ...
				       "position", [s.xtick(i) 0 0], ...
				       "rotation", 270, ...
				       "horizontalalignment", "right", ...
				       "verticalalignment", "middle");
      __uiobject_adopt__ (h, hc, "xticklabelobject");
    endfor
  endif

  ## check the y axis
  if strcmpi (s.yticklabelmode, "auto")
    ## delete any old axis labels
    ## FIXME: Perhaps we should check if there is a change to the axis
    ## here before doing all this work
    delete (s.yticklabelobject);

    ## create the new axis labels
    for i = 1:length (s.ytick)
      hc = __uiobject_create_object__ ("text", ...
				       "parent", h, ...
				       "string", num2str (s.xtick(i)), ...
				       "position", [0 s.xtick(i) 0], ...
				       "horizontalalignment", "right", ...
				       "verticalalignment", "middle");
      __uiobject_adopt__ (h, hc, "yticklabelobject");
    endfor
  endif

  ## check the z axis
  if strcmpi (s.zticklabelmode, "auto")
    ## delete any old axis labels
    ## FIXME: Perhaps we should check if there is a change to the axis
    ## here before doing all this work
    delete (s.zticklabelobject);

    ## create the new axis labels
    for i = 1:length (s.ztick)
      hc = __uiobject_create_object__ ("text", ...
				       "parent", h, ...
				       "string", num2str (s.ztick(i)), ...
				       "position", [0 0 s.ztick(i)], ...
				       "horizontalalignment", "right", ...
				       "verticalalignment", "middle");
      __uiobject_adopt__ (h, hc, "zticklabelobject");
    endfor
  endif

endfunction