## Copyright (C) 2005, 2006 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {@var{s}} __uiobject_default_root__ ()
## Return the structure of the default root object.
## @end deftypefn

## Author: jwe

function s = __uiobject_default_root__ ()

  if (nargin == 0)
    s.type = "root";
    s.currentfigure = [];
    s.children = [];
    s.currenttimestamp = 0;
    s.orphans = [];
    s.timestamp = 0;

    s.required.root = {"parent"};
    s.childprops.root = {"children"};

    ## default Axes properties
    s.default.axes.cameraposition = [0.5 0.5 0.5];
    s.default.axes.camerapositionmode = "auto";
    s.default.axes.cameraprojection = "orthographic";
    s.default.axes.cameratarget = [0.5 0.5 0];
    s.default.axes.cameratargetmode = "auto";
    s.default.axes.cameraupvector = [0 1 0];
    s.default.axes.cameraupvectormode = "auto";
    s.default.axes.cameraviewangle = 45;
    s.default.axes.cameraviewanglemode = "auto";
    s.default.axes.children = [];
    s.default.axes.color = [1 1 1 1];
    s.default.axes.colororder = [1 0 0 1; ...
				 0 1 0 1; ...
				 0 0 1 1; ...
				 1 1 0 1; ...
				 1 0 1 1; ...
				 0 1 1 1; ...
				 0 0 0 1];
    s.default.axes.gridlinestyle = ":";
    s.default.axes.gridlinewidth = 1;
    s.default.axes.lightcolor = [1 1 1 1];
    s.default.axes.lightposition = [1 1 0.5];
    s.default.axes.lightstyle = "infinite";
    ## FIXME: define this in the standard
    s.default.axes.lineorder = {"-"};
    s.default.axes.linewidth = 1;
    ## FIXME: define this in the standard
    s.default.axes.markerorder = {"*" "+" "o" "x" "." "none"};
    ## this is set by hold on or hold off
    s.default.axes.nextplot = "replace";
    s.default.axes.position = [0.2 0.8 0.6 0.6];
    ## this must be set upon object initialization
    s.default.axes.parent = [];
    s.default.axes.tag = "";
    ## this must be updated upon object modification
    s.default.axes.timestamp = [];
    s.default.axes.type = "axes";
    s.default.axes.visible = 1;
    s.default.axes.xcolor = [0 0 0 1];
    s.default.axes.ycolor = [0 0 0 1];
    s.default.axes.zcolor = [0 0 0 1];
    s.default.axes.xlabel = [];
    s.default.axes.ylabel = [];
    s.default.axes.zlabel = [];
    s.default.axes.xlim = [0 1];
    s.default.axes.ylim = [0 1];
    s.default.axes.zlim = [];
    s.default.axes.clim = [0 1];
    s.default.axes.xlimmode = "auto";
    s.default.axes.ylimmode = "auto";
    s.default.axes.zlimmode = "auto";
    s.default.axes.climmode = "auto";
    s.default.axes.xscale = "linear";
    s.default.axes.yscale = "linear";
    s.default.axes.zscale = "linear";
    s.default.axes.xtick = 0:0.2:1;
    s.default.axes.ytick = 0:0.2:1;
    s.default.axes.ztick = [];
    s.default.axes.xticklabel = {};
    s.default.axes.yticklabel = {};
    s.default.axes.zticklabel = {};
    s.default.axes.xticklabelobject = [];
    s.default.axes.yticklabelobject = [];
    s.default.axes.zticklabelobject = [];
    s.default.axes.xticklabelmode = "auto";
    s.default.axes.yticklabelmode = "auto";
    s.default.axes.zticklabelmode = "auto";

    s.required.axes = {"parent"};
    s.childprops.axes = {"children", ...
			 "xticklabelobject", ...
			 "yticklabelobject", ...
			 "zticklabelobject"};

    ## default figure properties
    s.default.figure.children = [];
    ## FIXME: I don't know how this should be initialized
    s.default.figure.colormap = [];
    ## this must be set upon axis creation and possibly updated upon
    ## axis deletion.  If there are any axes within this figure, it
    ## cannot be empty.
    s.default.figure.currentaxes = [];
    s.default.figure.filename = "";
    ## this must be set upon object initialization
    s.default.figure.number = [];
    ## this should never be changed
    s.default.figure.parent = 0;
    s.default.figure.position = [50 50 400 400];
    s.default.figure.tag = "";
    ## this must be updated upon object modification
    s.default.figure.timestamp = [];
    s.default.figure.type = "figure";
    s.default.figure.visible = 1;

    s.required.figure = {"number"};
    s.childprops.figure = {"children"};

    ## default group properties
    s.default.group.children = [];
    s.default.group.clipping = 1;
    ## this must be set upon object initialization
    s.default.group.parent = [];
    s.default.group.tag = "";
    ## this must be updated upon object modification
    s.default.group.timestamp = [];
    s.default.group.type = "group";
    s.default.group.visible = 1;

    s.required.group = {"parent"};

    ## default image properties
    s.default.image.clipping = 1;
    ## this must be set upon object initialization
    s.default.image.colormap = [];
    s.default.image.edgecolor = [0 0 0 1];
    ## this must be set upon object initialization
    s.default.image.imagedata = [];
    ## this should be set upon object initialization
    s.default.image.parent = [];
    s.default.image.tag = "";
    ## this must be updated upon object modification
    s.default.image.timestamp = [];
    s.default.image.type = "image";
    s.default.image.visible = 1;

    s.required.image = {"colormap", ...
			"imagedata", ...
			"parent"};
    s.childprops.image = {};

    ## default legend properties
    s.default.legend.clipping = 1;
    s.default.legend.edgecolor = [0 0 0 1];
    s.default.legend.facecolor = [1 1 1 1];
    s.default.legend.label = [];
    s.default.legend.line = [];
    s.default.legend.location = "ne";
    ## this should be set upon object initialization
    s.default.legend.parent = [];
    s.default.legend.patch = [];
    s.default.legend.tag = "";
    ## this must be updated upon object modification
    s.default.legend.timestamp = [];
    s.default.legend.type = "legend";
    s.default.legend.visible = 1;

    s.required.legend = {"parent"};
    s.childprops.legend = {};

    ## default line properties
    s.default.line.clipping = 1;
    ## this should be set upon object initialization
    s.default.line.color = [];
    s.default.line.label = [];
    s.default.line.linestyle = "-";
    s.default.line.linewidth = 1;
    s.default.line.marker = "";
    ## this should be set upon object initialization
    s.default.line.markeredgecolor = [];
    ## this should be set upon object initialization
    s.default.line.markerfacecolor = [];
    s.default.line.markersize = 1; 
    ## this should be set upon object initialization
    s.default.line.parent = [];
    s.default.line.tag = "";
    ## this must be updated upon object modification
    s.default.line.timestamp = [];
    s.default.line.type = "line";
    s.default.line.visible = 1;
    ## these should be set upon object initialization
    s.default.line.xdata = [];
    s.default.line.ydata = [];
    s.default.line.zdata = [];

    s.required.line = {"color", ...
		       "markeredgecolor", ...
		       "markerfacecolor", ...
		       "xdata", ...
		       "ydata"};
    s.childprops.line = {"label"};

    ## default movie properties
    s.default.movie.children = [];
    s.default.movie.childstartstop = [];
    s.default.movie.frames = [];
    s.default.movie.framespersecond = 30;
    s.default.movie.filename = "";
    s.default.movie.filetype = "mpg";
    ## this should never be changed
    s.default.movie.parent = 0;
    s.default.movie.position = [50 50 400 400];
    s.default.movie.tag = "";
    ## this must be updated upon object modification
    s.default.movie.timestamp = [];
    s.default.movie.type = "movie";
    s.default.movie.visible = 1;

    s.required.movie = {};
    s.childprops.movie = {"children"};

    ## default patch properties
    s.default.patch.clipping = 1;
    ## this should be set upon object initialization
    s.default.patch.edgecolor = [];
    ## this should be set upon object initialization
    s.default.patch.facecolor = [];
    s.default.patch.label = [];
    s.default.patch.linestyle = "-";
    s.default.patch.linewidth = 1;
    s.default.patch.marker = [];
    s.default.patch.markeredgecolor = [];
    s.default.patch.markerfacecolor = [];
    s.default.patch.markersize = [];
    ## this should be set upon object initialization
    s.default.patch.parent = [];
    s.default.patch.tag = "";
    ## this must be updated upon object modification
    s.default.patch.timestamp = [];
    s.default.patch.type = "patch";
    s.default.patch.visible = 1;
    ## these should be set upon object initialization
    s.default.patch.xdata = [];
    s.default.patch.ydata = [];
    s.default.patch.zdata = [];

    s.required.patch = {"edgecolor", ...
			"facecolor", ...
			"parent", ...
			"xdata", ...
			"ydata"};
    s.childprops.patch = {"label"};

    ## default surface properties
    s.default.surface.clipping = 1;
    s.default.surface.edgecolor = [];
    s.default.surface.facecolor = [];
    s.default.surface.linestyle = [];
    s.default.surface.linewidth = [];
    ## this should be set upon object initialization
    s.default.surface.parent = [];
    s.default.surface.tag = "";
    ## this must be updated upon object modification
    s.default.surface.timestamp = [];
    s.default.surface.type = "surface";
    s.default.surface.visible = 1;
    ## these should be set upon object initialization
    s.default.surface.xdata = [];
    s.default.surface.ydata = [];
    s.default.surface.zdata = [];

    s.required.surface = {"parent", ...
			  "xdata", ...
			  "ydata"};
    s.childprops.surface = {"label"};

    ## default text properties
    s.default.text.clipping = 1;
    s.default.text.color = [0 0 0 1];
    s.default.text.fontname = "ariel";
    s.default.text.fontsize = 12;
    s.default.text.horizontalalignment = "left";
    ## this should be set upon object initialization
    s.default.text.parent = [];
    ## this should be set upon object initialization
    s.default.text.position = [];
    s.default.text.rotation = 0;
    ## this should be set upon object initialization
    s.default.text.string = "";
    s.default.text.tag = "";
    ## this must be updated upon object modification
    s.default.text.timestamp = [];
    s.default.text.type = "text";
    s.default.text.verticalalignment = "bottom";
    s.default.text.visible = 1;

    s.required.text = {"parent", ...
		       "position", ...
		       "string"};
    s.childprops.text = {};

  else
    usage ("__uiobject_make_root_figure__ ()");
  endif

endfunction
