## Copyright (C) 2005, 2006 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {@var{v}} = __uiobject_default_valid__ ()
## Return the structure of the default validator object.  A function
## handle indicates that this function should receive the
## @end deftypefn

## Author: jwe

function v = __uiobject_default_valid__ ()

  if (nargin > 0)
    usage ("__uiobject_default_valid__ ()");
  endif

  ## functions to validate the properties with their arguements
  ## validator functions for root
  v.root.type = @__uiobject_valid_immutable__;
  v.root.currentfigure = {@__uiobject_valid_handlevector__, 1};
  v.root.children = {@__uiobject_valid_handlevector__, []};
  v.root.orphans = {@__uiobject_valid_handlevector__, []};
  v.root.timestamp = @__uiobject_valid_immutable__;

  ## validator functions for axes
  v.axes.cameraposition = {@__uiobject_valid_matrix__, 1, 3};
  v.axes.camerapositionmode = @__uiobject_valid_auto_manual__;
  v.axes.cameraprojection = {@__uiobject_valid_string_choose__, ...
			     "orthographic", "perspective"};
  v.axes.cameratarget = {@__uiobject_valid_matrix__, 1, 3};
  v.axes.cameratargetmode = @__uiobject_valid_auto_manual__;;
  v.axes.cameraupvector = {@__uiobject_valid_matrix__, 1, 3};
  v.axes.cameraupvectormode = @__uiobject_valid_auto_manual__;;
  v.axes.cameraviewangle = {@__uiobject_valid_scalar_range__, 0, 180};
  v.axes.cameraviewanglemode = @__uiobject_valid_auto_manual__;
  v.axes.children = {@__uiobject_valid_handlevector__, []};
  v.axes.color = @__uiobject_valid_color__;
  v.axes.colororder = {@__uiobject_valid_colorvector__, []};
  v.axes.gridlinestyle = @__uiobject_valid_linespec__;
  v.axes.gridlinewidth = {@__uiobject_valid_scalar_range__, 0, []};
  v.axes.lightcolor = @__uiobject_valid_color__;
  v.axes.lightposition = {@__uiobject_valid_matrix__, 1, 3};
  v.axes.lightstyle = {@__uiobject_valid_string_choose__, "infinite", "local"};
  v.axes.lineorder = @__uiobject_valid_linespec__;
  v.axes.linewidth = {@__uiobject_valid_scalar_range__, 0, []};
  ## FIXME: define this in the standard
  v.axes.markerorder = @__uiobject_valid_markerspec__;
  ## this is set by hold on or hold off
  v.axes.nextplot = {@__uiobject_valid_string_choose__, "add", "replace"};
  v.axes.position = {@__uiobject_valid_matrix_flex__, 1, 4};
  ## this must be set upon object initialization
  v.axes.parent = {@__uiobject_valid_handlevector__, 1};
  v.axes.tag = @__uiobject_valid_any__;
  v.axes.timestamp = @__uiobject_valid_immutable__;  
  v.axes.type = @__uiobject_valid_immutable__;
  v.axes.visible = @__uiobject_valid_boolean__;
  v.axes.xcolor = @__uiobject_valid_color__;
  v.axes.ycolor = @__uiobject_valid_color__;
  v.axes.zcolor = @__uiobject_valid_color__;
  v.axes.xlim = {@__uiobject_valid_matrix_flex__, 1, 2};
  v.axes.ylim = {@__uiobject_valid_matrix_flex__, 1, 2};
  v.axes.zlim = {@__uiobject_valid_matrix_flex__, 1, 2};
  v.axes.clim = {@__uiobject_valid_matrix_flex__, 1, 2};
  v.axes.xlimmode = @__uiobject_valid_auto_manual__;
  v.axes.ylimmode = @__uiobject_valid_auto_manual__;
  v.axes.zlimmode = @__uiobject_valid_auto_manual__;
  v.axes.climmode = @__uiobject_valid_auto_manual__;
  v.axes.xlabel = @__uiobject_valid_string__;
  v.axes.ylabel = @__uiobject_valid_string__;
  v.axes.zlabel = @__uiobject_valid_string__;
  v.axes.xscale = {@__uiobject_valid_string_choose__, "linear", "log"};
  v.axes.yscale = {@__uiobject_valid_string_choose__, "linear", "log"};
  v.axes.zscale = {@__uiobject_valid_string_choose__, "linear", "log"};
  v.axes.xtick = {@__uiobject_valid_matrix_flex__, [], 1};
  v.axes.ytick = {@__uiobject_valid_matrix_flex__, [], 1};
  v.axes.ztick = {@__uiobject_valid_matrix_flex__, [], 1};
  v.axes.xticklabelobject = {@__uiobject_valid_handlevector__, []};
  v.axes.yticklabelobject = {@__uiobject_valid_handlevector__, []};
  v.axes.zticklabelobject = {@__uiobject_valid_handlevector__, []};
  v.axes.xticklabelmode = @__uiobject_valid_auto_manual__;
  v.axes.yticklabelmode = @__uiobject_valid_auto_manual__;
  v.axes.zticklabelmode = @__uiobject_valid_auto_manual__;

  ## default figure properties
  v.figure.children = {@__uiobject_valid_handlevector__, []};
  v.figure.colormap = {@__uiobject_valid_matrix_flex__, [], 1};
  v.figure.currentaxes = {@__uiobject_valid_handlevector__, 1};
  v.figure.filename = @__uiobject_valid_string__;
  v.figure.number = {@__uiobject_valid_matrix__, 1, 1};
  v.figure.parent = @__uiobject_valid_immutable__;
  v.figure.position = {@__uiobject_valid_matrix_flex__, 1, 4};
  v.figure.tag = @__uiobject_valid_any__;
  v.figure.timestamp = @__uiobject_valid_immutable__;
  v.figure.type = @__uiobject_valid_immutable__;
  v.figure.visible = @__uiobject_valid_boolean__;

  ## default group properties
  v.group.children = {@__uiobject_valid_handlevector__, []};
  v.group.clipping = @__uiobject_valid_boolean__;
  v.group.parent = {@__uiobject_valid_handlevector__, 1};
  v.group.tag = @__uiobject_valid_any__;
  v.group.timestamp = @__uiobject_valid_immutable__;
  v.group.type = @__uiobject_valid_immutable__;
  v.group.visible = @__uiobject_valid_boolean__;

  ## default image properties
  v.image.clipping = @__uiobject_valid_boolean__;
  v.image.colormap = {@__uiobject_valid_matrix__, [], 1};
  v.image.edgecolor = @__uiobject_valid_color__;
  v.image.imagedata = {@__uiobject_valid_matrix__, [], []};
  v.image.parent = {@__uiobject_valid_handlevector__, 1};
  v.image.tag = @__uiobject_valid_any__;
  v.image.timestamp = @__uiobject_valid_immutable__;
  v.image.type = @__uiobject_valid_immutable__;
  v.image.visible = @__uiobject_valid_boolean__;

  ## default legend properties
  v.legend.clipping = @__uiobject_valid_boolean__;
  v.legend.edgecolor = @__uiobject_valid_color__;
  v.legend.facecolor = @__uiobject_valid_color__;
  v.legend.label = {@__uiobject_valid_handlevector__, []};
  v.legend.line = {@__uiobject_valid_handlevector__, []};
  v.legend.location = {@__uiobject_valid_string_choose__, ...
		       "nw", "n", "ne", "w", "e", "sw", "s", "se"};
  ## this should be set upon object initialization
  v.legend.parent = {@__uiobject_valid_handlevector__, 1};
  v.legend.patch = {@__uiobject_valid_handlevector__, []};
  v.legend.tag = @__uiobject_valid_any__;
  v.legend.timestamp = @__uiobject_valid_immutable__;
  v.legend.type = @__uiobject_valid_immutable__;
  v.legend.visible = @__uiobject_valid_boolean__;

  ## default line properties
  v.line.clipping = @__uiobject_valid_boolean__;
  ## this should be set upon object initialization
  v.line.color = @__uiobject_valid_color__;
  v.line.label = {@__uiobject_valid_handlevector__, 1};
  v.line.linestyle = @__uiobject_valid_linespec__;
  v.line.linewidth = {@__uiobject_valid_scalar_range__, 0, []};
  v.line.marker = @__uiobject_valid_markerspec__;
  v.line.markeredgecolor = @__uiobject_valid_color__;
  v.line.markerfacecolor = @__uiobject_valid_color__;
  v.line.markersize = {@__uiobject_valid_scalar_range__, 0, []};
  v.line.parent = {@__uiobject_valid_handlevector__, 1};
  v.line.tag = @__uiobject_valid_any__;
  v.line.timestamp = @__uiobject_valid_immutable__;
  v.line.type = @__uiobject_valid_immutable__;
  v.line.visible = @__uiobject_valid_boolean__;
  v.line.xdata = {@__uiobject_valid_matrix_flex__, [], 1};
  v.line.ydata = {@__uiobject_valid_matrix_flex__, [], 1};
  v.line.zdata = {@__uiobject_valid_matrix_flex__, [], 1};

  ## default movie properties
  v.movie.children = {@__uiobject_valid_handlevector__, []};
  v.movie.childstartstop = {@__uiobject_valid_matrix__, [], 2};
  v.movie.frames = {@__uiobject_valid_handlevector__, []};
  v.movie.framespersecond = {@__uiobject_valid_scalar_range__, 0, []};
  v.movie.filename = @__uiobject_valid_string__;
  v.movie.filetype = @__uiobject_valid_string__;
  v.movie.parent = @__uiobject_valid_immutable__;
  v.movie.position = {@__uiobject_valid_matrix__, 1, 1};
  v.movie.tag = @__uiobject_valid_any__;
  v.movie.timestamp = @__uiobject_valid_immutable__;
  v.movie.type = @__uiobject_valid_immutable__;
  v.movie.visible = @__uiobject_valid_boolean__;

  ## default patch properties
  v.patch.clipping = @__uiobject_valid_boolean__;
  v.patch.edgecolor = @__uiobject_valid_color__;
  v.patch.facecolor = @__uiobject_valid_color__;
  v.patch.label = {@__uiobject_valid_handlevector__, 1};
  v.patch.linestyle = @__uiobject_valid_linespec__;
  v.patch.linewidth = {@__uiobject_valid_scalar_range__, 0, []};
  v.patch.marker = @__uiobject_valid_markerspec__;
  v.patch.markeredgecolor = @__uiobject_valid_color__;
  v.patch.markerfacecolor = @__uiobject_valid_color__;
  v.patch.markersize = {@__uiobject_valid_scalar_range__, 0, []};
  v.patch.parent = {@__uiobject_valid_handlevector__, 1};
  v.patch.tag = @__uiobject_valid_any__;
  v.patch.timestamp = @__uiobject_valid_immutable__;
  v.patch.type = @__uiobject_valid_immutable__;
  v.patch.visible = @__uiobject_valid_boolean__;
  v.patch.xdata = {@__uiobject_valid_matrix_flex__, [], 1};
  v.patch.ydata = {@__uiobject_valid_matrix_flex__, [], 1};
  v.patch.zdata = {@__uiobject_valid_matrix_flex__, [], 1};

  ## default surface properties
  v.surface.clipping = @__uiobject_valid_boolean__;
  v.surface.edgecolor = @__uiobject_valid_color__;
  v.surface.facecolor = @__uiobject_valid_color__;
  v.surface.linestyle = @__uiobject_valid_linespec__;
  v.surface.linewidth = {@__uiobject_valid_scalar_range__, 0, []};
  v.surface.parent = {@__uiobject_valid_handlevector__, 1};
  v.surface.tag = @__uiobject_valid_any__;
  v.surface.timestamp = @__uiobject_valid_immutable__;
  v.surface.type = @__uiobject_valid_immutable__;
  v.surface.visible = @__uiobject_valid_boolean__;
  v.surface.xdata = {@__uiobject_valid_matrix_flex__, [], 1};
  v.surface.ydata = {@__uiobject_valid_matrix_flex__, [], 1};
  v.surface.zdata = {@__uiobject_valid_matrix_flex__, [], 1};

  ## default text properties
  v.text.clipping = @__uiobject_valid_boolean__;
  v.text.color = @__uiobject_valid_color__;
  v.text.fontname = @__uiobject_valid_string__;
  v.text.fontsize = {@__uiobject_valid_scalar_range__, 0, []};
  v.text.horizontalalignment = {@__uiobject_valid_string_choose__, ...
				"left", "center", "right"};
  v.text.parent = {@__uiobject_valid_handlevector__, 1};
  v.text.position = {@__uiobject_valid_matrix__, 1, 3};
  v.text.rotation = {@__uiobject_valid_scalar_range__, 0, 360};
  v.text.string = @__uiobject_valid_string__;
  v.text.tag = @__uiobject_valid_any__;
  v.text.timestamp = @__uiobject_valid_immutable__;
  v.text.type = @__uiobject_valid_immutable__;
  v.text.verticalalignment = {@__uiobject_valid_string_choose__, ...
			      "bottom", "middle", "top"};
  v.text.visible = @__uiobject_valid_boolean__;

endfunction
