## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} __uiobject_move_object__ (n, f)
## Move an object number from @var{n} to @var{f}.
## @end deftypefn

## Author: Bill Denney

function __uiobject_move_object__ (n, f)

  ## this function is mainly for moving figure numbers when they are
  ## given by the user

  if (sign (n) ~= sign (f))
    ## Check to make sure that we're not trying to move from one object
    ## type to another.
    error ("__uiobject_move_object__: object numbers are not of the same type");
  elseif (floor (f) ~= f)
    ## Check to make sure that both numbers could be valid handles.
    error ("__uiobject_move_object__: f (%g) is not a valid object number", f);
  elseif (floor (n) ~= n)
    error ("__uiobject_move_object__: n (%g) is not a valid object number", n);
  elseif ishandle (f)
    ## check to see if the number is already used
    error ("__uiobject_move_object__: cannot move object number from %d to %d, %d is already in use", n, f, f);
  else
    __uiobject_globals__;

    idx = __uiobject_handle2idx__ (n);
    __uiobject_list_status__(idx).handle = f;
  endif

endfunction