## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} __uiobject_orphan__ (@var{h})
## Remove child @var{h} from its parent and put it on the
## root orphans list.  @var{h} may be a handle vector.
## @seealso{__uiobject_adopt__}
## @end deftypefn

## Author: Bill Denney

function __uiobject_orphan__ (h)

  if (nargin == 0)
    usage ("__uiobject_orphan__ (h);");
  elseif any (~ ishandle (h))
    error ("__uiobject_orphan__: h must be a handle");
  endif

  ## FIXME: this should be better vectorized
  for i = 1:numel (h)
    ## remove it from its parent
    hp = get (h(i), "parent");
    if (~ isempty (hp))
      ## it has a parent, otherwise, it's already an orphan

      ## try all the child types for the parent object type
      ptype = get (hp, "type");
      kidtypes = get (0, ["ChildProps." ptype]);
      for j = 1:length (kidtypes)
	pkids = get (hp, kidtypes{j});
	pkids(ismember (pkids, h(i))) = [];
	set (hp, kidtypes{j}, pkids);
      endfor
    endif
  endfor

  orph = get (0, "orphans");
  h = reshape(h, [], 1);
  orph = [orph;h];
  set (0, "orphans", orph);

endfunction