## Copyright (C) 2005, 2006 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {[@var{val} @var{err}]} = __uiobject_validate__ (@var{objtype}, @var{prop}, @var{val})
## Cleans and validate the @var{val} to set for a @var{prop} for the
## object type @var{objtype}.  If the input is valid, a cleaned version
## of the value will be returned (i.e. if a 1x3 vector is desired, but a
## 3x1 is given, return the 1x3 reshaped version).  If the input is
## invalid, a non-empty error message is returned.
##
## The validation functions are in the validators sub-directory.
## @seealso{set,__uiobject_default_root__}
## @end deftypefn

## Author: jwe

function [val, err] = __uiobject_validate__ (objtype, prop, val)

  persistent v;
  if isempty (v)
    v = __uiobject_default_valid__ ();
  endif

  objtype = lower (objtype);
  prop = lower (prop);

  ## check to see if the object type exists
  if (~ isfield (v, objtype))
    val = [];
    err = sprintf("there is no uiobject type %s", objtype);
  elseif (~ isfield (v.(objtype), prop))
    val = [];
    err = sprintf("has no field %s", prop);
  else
    tstfun = v.(objtype).(prop);
    if iscell (tstfun)
      args = tstfun(2:length (tstfun));
      tstfun = tstfun{1};
    else
      args = {};
    endif

    [val, err] = tstfun (objtype, prop, val, args{:});
  endif

endfunction