## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} allchild (@var{h})
## Returns all child elements of @var{h}.  If @var{h} is a vector,
## returns a cell vector.
## @seealso{__uiobject_adopt__}
## @end deftypefn

## Author: Bill Denney

function retval = allchild (h)

  if (nargin ~= 1)
    usage ("allchild (h);");
  elseif (~ all (ishandle (h)))
    error ("allchild: h must be a handle");
  endif

  ## FIXME: this should be better vectorized
  for i = 1:length (h(:))
    htype = get (h(i), "type");
    kidtypes = get (0, ["ChildProps." htype]);
    retval{i} = [];
    for j = 1:length (kidtypes)
      thesekids = get (h(i), kidtypes{j});
      retval{i} = [retval{i} thesekids];
      for k = 1:length (thesekids)
	subkids = allchild (thesekids(k));
	retval{i} = [retval{i} subkids];
      endfor
    endfor
  endfor

  if (prod (size (retval)) == 1)
    retval = retval{1};
  else
    retval = reshape (retval, size (h));
  endif

endfunction