## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} ancestor (@var{h}, @var{type})
## @deftypefnx {Function File} {} ancestor (@var{h}, @var{type}, "toplevel")
## Returns the closest ancestor of @var{h} that is a given @var{type}.
## If "toplevel" is specified, then it returns the farthest ancestor
## that is the given @var{type}.  If no ancestor is found with the given
## type, empty is returned.
## @seealso{allchild}
## @end deftypefn

## Author: Bill Denney

function retval = ancestor (h, objtype, toplevel)

  if ((nargin < 1) || (nargin > 3))
    usage ("ancestor (h);");
  elseif (~ all (ishandle (h)))
    error ("ancestor: h must be a handle");
  elseif (~ ischar (objtype))
    error ("ancestor: objtype must be a string");
  endif

  ## process the input arguements

  if strcmpi (toplevel, "toplevel")
    toplevel = 1;
  else
    toplevel = 0;
  endif

  found = 0;
  retval = [];
  hc = h; # current handle
  while (~ found)
    hp = get (hc, "parent");
    ptype = get (hp, "type");
    if strcmpi (ptype, objtype)
      retval = hp;
    endif

    hc = hp;

    ## decide if we're done
    if strcmpi (ptype, "root")
      ## when we reach the root there's nowhere else to go
      found = 1;
    elseif (~ toplevel && ~ isempty (retval))
      ## if we don't need the toplevel and we've found something we're
      ## done
      found = 1;
    endif
  endwhile

endfunction