## Copyright (C) 2005, 2006 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} axes ()
## @deftypefnx {Function File} {} axes (@var{property}, @var{value}, @dots{})
## @deftypefnx {Function File} {} axes (@var{h})
## Create an axes object and return a handle to it.
## @end deftypefn

## Author: jwe

function h = axes (varargin)

  ## If we have an even number of arguments, they should be
  ## property-value pirs.

  have_properties_to_set = (nargin > 0 && rem (nargin, 2) == 0);

  if (nargin == 0 || have_properties_to_set)
    ## make default axes object, and make it the current axes for the
    ## current figure.
    cf = gcf ();
    h = __uiobject_create_object__ ("axes", ...
				    "parent", cf, ...
				    varargin{:});
    __uiobject_autolabel_axes__ (h);
    __uiobject_adopt__ (cf, h);
    ## make this axis the current axis
    set (cf, "currentaxes", h);
  elseif (nargin == 1)
    ## arg is axes handle, make it the current axes and make its figure
    ## the current figure
    h = varargin{1};
    if (isscalar (h) && ishandle (h) && strcmp (get (h, "type"), "axes"))
      pf = get (h, "parent");
      set (pf, "currentaxes", h);
      set (0, "currentfigure", pf);
    else
      error ("axes: expecting argument to be axes handle");
    endif
  else
    usage ("axes ()");
  endif

endfunction
