## Copyright (C) 2005 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} clf ()
## @deftypefnx {Function File} {@var{f}} = clf (@var{f})
## Clear the current figure, or if @var{f} is specified, clear figure
## @var{f}.
## @end deftypefn

## Author: jwe

function f = clf (n, reset)

  if (nargin == 0)
    n = gcf ();
  elseif (nargin < 3)
    ## if nargin == 2, it should just be "reset" which can be ignored
    ## since we don't use hidden child objects (yet?).
    if (~ isfigure (n))
      error ("clf: f must be a figure object");
    endif
  else
    usage ("clf ()");
  endif

  obj = get (n);
  delete (allchild (n));
  set (n, "currentaxes", []);
  drawnow ();

  if (nargout == 1)
    f = n;
  endif

endfunction
