## Copyright (C) 2002 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Command} {} close
## @deftypefnx {Command} {} close (@var{n})
## @deftypefnx {Command} {} close all
## @deftypefnx {Command} {} close all hidden
## Close the plot window(s).
## @end deftypefn

## Author: jwe

## PKG_ADD: mark_as_command close

function retval = close (varargin)

  if (nargin == 0)
    ## Close current figure.
    figs = gcf ();
  elseif (nargin == 1)
    if (ischar (varargin{1}) && strcmp (varargin{1}, "all"))
      ## Close all figures.
      figs = get (0, "children");
    elseif (all (isfigure (varargin{:})))
      figs = cell2mat (varargin);
    else
      error ("close: expecting argument to be \"all\" or a figure handle");
    endif
  elseif (nargin == 2
	  && ischar (varargin{1}) && strcmp (varargin{1}, "all")
	  && ischar (varargin{2}) && strcmp (varargin{2}, "hidden"))
    figs = get (0, "children");
  else
    usage ("close (...)");
  endif

  for h = figs
    delete (h);
    ## FIXME: We don't have a close request function
    ## set (0, "currentfigure", h);
    ## feval (get (h, "closerequestfcn"));
  endfor

  ## set the current figure to the most recent child figure
  kids = get (0, "children");
  if isempty (kids)
    lastkid = [];
  else
    lastkid = kids(length (kids));
  endif
  set (0, "currentfigure", lastkid);

  if (nargout > 0)
    retval = 1;
  endif

endfunction
