## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} delete (@var{h})
## Delete the object with handle @var{h} including removing it from its
## parent and recursively deleting all of its children.  @var{h} may be
## a vector.
## @end deftypefn

## Author: Bill Denney

function delete (h)

  ## check input arguements
  if (nargin ~= 1)
    usage ("delete (h)");
  elseif isempty (h)
    ## warning ("delete: h cannot be empty");
    return;
  elseif any (h == 0)
    error ("delete: cannot delete the root object");
  endif

  __uiobject_globals__;

  ## allow vector input
  h = reshape (h, 1, []);

  ## Remove them from their parents
  __uiobject_orphan__ (h);

  ## find all children to kill
  hc = allchild (h);
  if iscell (hc)
    hc = cat (2, cell2mat (hc), h);
  else
    hc = cat (2, hc, h);
  endif

  idx = __uiobject_handle2idx__ (hc);

  ## clear all fields of the object and free it
  __uiobject_list__{idx} = struct([]);
  __uiobject_list_status__(idx).handle = NaN;
  __uiobject_list_status__(idx).in_use = false;

  ## Remove them from the orphan list
  orph = get (0, "orphans");
  orph = orph(~ ismember (orph, hc));
  set (0, "orphans", orph);

endfunction
