## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} figure ()
## @deftypefnx {Function File} {} figure (@var{n})
## @deftypefnx {Function File} {} figure (@var{n}, @var{prop}, @var{val}, @dots{})
## Set the current plot window to plot window @var{n}.  If @var{n} is
## not specified, the next available figure number is chosen.
## Optionally, properties and values may be set for the figure object.
## @end deftypefn

## Author: Bill Denney

function f = figure (varargin)

  f = [];
  if (nargin == 0)
    ## do nothing right now
  elseif (mod (nargin, 2) == 1)
    if (ishandle (varargin{1}) && strcmp (get (varargin{1}, "type"), "figure"))
      f = varargin{1};
    endif
  else
    usage ("figure (n, prop, val, ...)");
  endif

  if isempty (f)
    ## create a new figure
    n = __uiobject_create_object__ ("figure", "number", 1);
    ## change the figure number if necessary
    if ((nargin > 0) && (n ~= f))
      __uiobject_move_object__ (n, f);
    else
      f = n;
    endif
    set (f, "number", f);
  endif

  if (nargin > 1)
    set (f, varargin{2:length(varargin)});
  endif
  __uiobject_adopt__ (0, f);
  set (0, "currentfigure", f);
  drawnow ();

endfunction
