## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} hold ()
## @deftypefnx {Function File} {} hold (@var{state})
## @deftypefnx {Function File} {} hold (@var{state}, @var{h}, ...)
## @deftypefnx {Function File} {} hold (@var{h}, ...)
## Sets the hold state of the current axis.  If no @var{state} is given, then
## the hold state is toggled for the current axis handle.  If one or
## more axis handles are given, then the state (if given or toggled if
## not given) is set for the given handles.
##
## @var{state} must be either "on" or "off".
##
## If no axis handle exists when hold is called, then an axis is created.
## @seealso{ishold}
## @end deftypefn

## Author: Bill Denney

## PKG_ADD: mark_as_command hold

function hold (varargin)

  ## any number of input arguements are possible
  state = [];
  if (nargin == 0)
    ## if there is no axis specified, use the current axis
    ax = gca ();
  elseif ischar (varargin{1})
    ## if the first arguement is a state, figure out what state it is
    ## and set that
    state = lower (varargin{1});
    if strcmp (state, "on")
      state = "add";
    elseif strcmp (state, "off")
      state = "replace";
    else
      error ("hold: state must be \"on\" or \"off\"");
    endif
    ax = cell2mat (varargin(2:length (varargin)));
    if isempty (ax)
      ax = gca ();
    endif
  elseif ishandle (varargin{1})
    ## if the first arguement is a handle, select all axes given
    ax = cell2mat (varargin);
  else
    usage ("hold (state)");
  endif

  if all((ishandle (ax(i)) & strcmp (get (ax, "type"), "axes")))
    ## if it is the correct type of handle
    if isempty (state)
      ## if the state is not given in the input arguements, toggle the
      ## state
      axstate = get (ax, "nextplot");
      changetoreplace = strcmp(axstate, "add");
      set (ax(changetoreplace), "nextplot", "replace");
      set (ax(~ changetoreplace), "nextplot", "add");
    else
      ## if the state is given in the input arguements, set it
      set (ax, "nextplot", state);
    endif
  else
    error ("hold: input is not an axis handle");
  endif

endfunction
