## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} ishold ()
## @deftypefnx {Function File} {} ishold (@var{h}, ...)
## Determines the hold state of the current axis.  If one or more axis
## handles are given, then the state for the given handles are returned.
##
## If no axis handle exists when ishold is called, then an axis is
## created.
## @seealso{hold}
## @end deftypefn

## Author: Bill Denney

function retval = ishold (varargin)

  ## any number of input arguements are possible
  state = [];
  if (nargin == 0)
    ## if there is no axis specified, use the current axis
    ax = gca ();
  else
    ## if the first arguement is a handle, select all axes given
    ax = [varargin{:}];
  endif

  if (ishandle (ax) && strcmp (get (ax, "type"), "axes"))
    ## if it is the correct type of handle
    retval = strcmp(get (ax, "nextplot"), "add");
  else
    error ("hold: %d is not an axis handle", ax(i));
  endif

endfunction
