## Copyright (C) 2005, 2006 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} line (@var{x}, @var{y})
## @deftypefnx {Function File} {} line (@var{x}, @var{y}, @var{z})
## @deftypefnx {Function File} {} line (@var{x}, @var{y}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} line (@var{x}, @var{y}, @var{z}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} line (@var{prop}, @var{val}, @dots{})
## Create line object from @var{x}, @var{y}, and @var{z} and insert in
## current axes object.  Alternatively, a line can be created from the
## properties and values, and any legal properties and values can be
## added when creating the line.  Return handle to line object.
## @end deftypefn

## Author: Bill Denney

function h = line (varargin)

  if (nargin < 2)
    usage ("line (...)");
  endif

  propstart = 1;

  if (isnumeric (varargin{1}) && isnumeric (varargin{2}))
    ## make these arguements into xdata and ydata respectively
    s.xdata = varargin{1};
    s.ydata = varargin{2};
    propstart = 3;
    if ((nargin > 2) && isnumeric (varargin{3}))
      s.zdata = varargin{3};
      propstart = 4;
    endif
  endif

  s.parent = gca ();

  ## convert the properties into a struct
  if (mod(length (varargin) - propstart, 2) == 0)
    error ("line: Invalid number of properties");
  endif
  for i = propstart:2:length (varargin)
    s.(lower (varargin{i})) = varargin{i+1};
  endfor

  ## set the default colors
  if (~ isfield (s, "color"))
    axcolors = get (gca (), "colororder");
    s.color = axcolors(1,:);
    ## rotate through the colors
    axcolors = axcolors(2:length(axcolors),:);
    axcolors = [axcolors; s.color];
    set (gca (), "colororder", axcolors);
  endif
  if (~ isfield (s, "markeredgecolor"))
    s.markeredgecolor = s.color;
  endif
  if (~ isfield (s, "markerfacecolor"))
    s.markerfacecolor = s.color;
  endif

  ## make a default line object, and make it the current axes for
  ## the current figure.

  ## check to see if hold is on, and if it isn't, clear the children of
  ## the axis
  if (~ ishold ())
    delete (get (gca (), "children"));
  endif
  h = __uiobject_create_object__ ("line", s);
  __uiobject_adopt__ (gca (), h);

endfunction
