## Copyright (C) 2006 Bill Denney
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} patch (@var{x}, @var{y}, @var{c})
## @deftypefnx {Function File} {} patch (@var{x}, @var{y}, @var{z}, @var{c})
## @deftypefnx {Function File} {} patch (@var{x}, @var{y}, @var{c}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} patch (@var{x}, @var{y}, @var{z}, @var{c}, @var{prop}, @var{val}, @dots{})
## @deftypefnx {Function File} {} patch (@var{prop}, @var{val}, @dots{})
## Create patch object from @var{x}, @var{y}, and @var{z} and insert in
## current axes object.  Alternatively, a patch can be created from the
## properties and values, and any legal properties and values can be
## added when creating the patch.  Return handle to patch object.
## @end deftypefn

## Author: Bill Denney

function h = patch (varargin)

  if (nargin < 3)
    usage ("patch (...)");
  endif

  properties = varargin;

  if (isnumeric (varargin{1}) && ...
      isnumeric (varargin{2}) && ...
      isnumeric (varargin{3}))
    ## make these arguements into xdata and ydata respectively
    propstart = {"xdata" varargin{1} ...
		 "ydata" varargin{2}};
    properties = properties(3:length (properties));
    if ((nargin > 3) && isnumeric (varargin{4}))
      propstart = {propstart{:} ...
		   "zdata" varargin{3} ...
		   "facecolor" varargin{4} ...
		   "edgecolor" varargin{4}};
      properties = properties(3:length (properties));
    else
      propstart = {propstart{:} ...
		   "facecolor" varargin{4} ...
		   "edgecolor" varargin{4}};
      properties = properties(2:length (properties));      
    endif
    properties = {propstart{:} properties{:}};
  endif

  ## make a default patch object, and make it the current axes for
  ## the current figure.

  ## NOTE: for compatibility, we ignore the status of hold
  ## if (~ ishold ())
  ##   delete (get (gca (), "children"));
  ## endif
  h = __uiobject_create_object__ ("patch", "parent", gca (), ...
				  properties{:});
  __uiobject_adopt__ (gca (), h);

endfunction
