## Copyright (C) 2005, 2006 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
## 02110-1301, USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} set (@var{h}, @var{p}, @var{v}, @dots{})
## Set the named property @var{p} to the value @var{v} in the graphics
## object @var{h}.
## @seealso{get}
## @end deftypefn

## Author: Bill Denney

function retval = set (h, varargin)

  __uiobject_globals__;
  if (nargin == 0)
    usage ("set (h, property, value, ...)");
  elseif isempty (h)
    error ("set: h cannot be empty");
  elseif (~ all (ishandle (h(:))))
    error ("set: h must be a handle or handle or handle vector");
  elseif (mod (nargin, 2) == 0)
    error ("set: invalid number of input arguements");
  endif

  idx = __uiobject_handle2idx__ (h);
  obj = __uiobject_list__(idx);

  ## FIXME: this could probably be vectorized better
  for i = 1:numel (obj)
    obj{i}.timestamp = __uiobject_update_timestamp__ ();

    for j = 1:2:nargin-1
      property = varargin{j};
      key = tolower (property);
      if (~ ischar (key))
	error ("set: expecting property to be a character string");
      elseif (strcmp (obj{i}.type, "root") && ~ isempty (strfind (key, ".")))
	## allow for the special default values here
	periods = strfind (key, ".");

	if (length (periods) ~= 2)
	  ## you cannot set all the properties as a structure, you must
	  ## set them individually
	  error ("set: Cannot set all properties of default items");
	elseif strncmp (key, "default", 7)
	  objtype = key(periods(1)+1:periods(2)-1);
	  proptype = key(periods(2)+1:length(key));
	  [val, err] = __uiobject_validate__ (objtype, proptype, ...
					      varargin{j+1});

	  if isempty (err)
	    obj{i}.default.(objtype).(proptype) = val;
	  else
	    error ("set: invalid default, %s's property %s %s", ...
		   objtype, proptype, err);
	  endif

	else
	  error ("set: can only set default sub-properties of root, no other derived sub-property types");
	endif

	## end handling the special default settings case

      elseif (~ isfield (obj{i}, key))
	error ("set: invalid property name `%s' for uiobject type %s",
	       property, obj{i}.type);
      else
	[val, err] = __uiobject_validate__ (obj{i}.type, key, varargin{j+1});
	if isempty (err)
	  obj{i}.(key) = varargin{j+1};
	else
	  error ("set: %s's property %s %s", obj{i}.type, property, err);
	endif
      endif
    endfor
  endfor

  ## if everything went correctly, put the object back in place
  __uiobject_list__(idx) = obj;
endfunction
